@@ -59,6 +59,9 @@ function(y, x, by, data, export=FALSE, name= "output", folder=getwd(), config) {
                              2*data[[config$variables$weight]]*data[[config$variables$jackknifeRep]], 
                                     data[[config$variables$weight]]))
       rp.wt.n <- nrow(data)*rp.wt/apply(rp.wt, 2, sum)
+      
+      if (isTRUE(config$parameters$varpv1)) {
+        
       # Replicate weights coefficients for sampling error
       reg.rp <- suppressWarnings(lapply(1:max(data[[config$variables$jackknifeZone]]), function(rp) 
                       summary(glm(formula=as.formula(regform), 
@@ -74,7 +77,7 @@ function(y, x, by, data, export=FALSE, name= "output", folder=getwd(), config) {
       # Total weighted coefficients
       coef.tot <- reg.tot$coefficients[, 1]
       # Sampling error 
-      coef.se <- (0.05*apply((coef.rp-coef.tot)^2, 1, sum))^(1/2)
+      coef.se <- mean(apply((coef.rp-coef.tot)^2, 1, sum))^(1/2)
       t.stat <- coef.tot/coef.se
       # Odds ratios and confidence intervals
       OR <- exp(coef.tot)
@@ -89,6 +92,50 @@ function(y, x, by, data, export=FALSE, name= "output", folder=getwd(), config) {
       results <- list("replicates"=coef.rp, "reg"=log.tab)
       return(results)
       
+      } else {
+      
+        rp.wt2 <- sapply(1:max(data[[config$variables$jackknifeZone]]), function(x) 
+          ifelse(data[[config$variables$jackknifeZone]] == x, 
+                 2*data[[config$variables$weight]]*ifelse(data[[config$variables$jackknifeRep]]==1,0,1), data[[config$variables$weight]]))
+        
+        rp.wt <- cbind(rp.wt2, rp.wt)
+        
+        
+        rp.wt.n <- nrow(data)*rp.wt/apply(rp.wt, 2, sum)
+        
+        
+        # Replicate weights coefficients for sampling error
+        reg.rp <- suppressWarnings(lapply(1:ncol(rp.wt), function(rp) 
+          summary(glm(formula=as.formula(regform), 
+                      family=quasibinomial("logit"), weights=rp.wt.n[, rp], data=data))))
+        
+        # Combine coefficients 
+        coef.rp <- do.call("cbind", lapply(1:ncol(rp.wt), function(rp) 
+          reg.rp[[rp]]$coefficients[,1]))
+        # Total weighted coefficient for each PV for imputation (between) error
+        reg.tot <- suppressWarnings(summary(glm(formula=as.formula(regform), family=quasibinomial("logit"), 
+                                                weights=nrow(data)*data[[config$variables$weight]]/sum(data[[config$variables$weight]]), data=data)))
+        
+        # Total weighted coefficients
+        coef.tot <- reg.tot$coefficients[, 1]
+        # Sampling error 
+        coef.se <- mean(apply((coef.rp-coef.tot)^2, 1, sum)/2)^(1/2)
+        t.stat <- coef.tot/coef.se
+        # Odds ratios and confidence intervals
+        OR <- exp(coef.tot)
+        # OR confidence intervals 
+        CI95low <- exp(coef.tot - 1.96*coef.se)
+        CI95up <- exp(coef.tot + 1.96*coef.se)
+        
+        # Table with estimates
+        log.tab <- data.frame("Coef."=coef.tot, "Std. Error"=coef.se, "t value"=t.stat, 
+                              as.data.frame(cbind(OR, CI95low, CI95up)), check.names=F)
+        
+        results <- list("replicates"=coef.rp, "reg"=log.tab)
+        return(results)
+        
+      }  
+        
     }
     if (config$parameters$weights == "mixed_piaac") {
       # mixed design, different for different coutnries
