@@ -56,7 +56,8 @@ timss4_conf <- list(variables = list(pvlabelpref="BSMMAT",
                    parameters = list(cutoffs = c(400, 475, 550, 625),
                                      percentiles = c(5, 10, 25, 75, 90, 95),
                                      weights = "JK",
-                                     PVreps = 5),
+                                     PVreps = 5,
+                                     varpv1=TRUE),
                    input = list(type = "IEA",
                                 prefixes = c("asg", "ash", "acg", "ast", "atg"),
                                 student = "asg",
@@ -74,6 +75,8 @@ timss4_conf <- list(variables = list(pvlabelpref="BSMMAT",
                                 type_part = c(-11, -9),
                                 cnt_part = c(-8, -6))
 )
+
+
 timss8_conf <- list(variables = list(pvlabelpref="BSMMAT", 
                                      pvlabelsuff = "",
                                      weight="TOTWGT",
@@ -82,7 +85,8 @@ timss8_conf <- list(variables = list(pvlabelpref="BSMMAT",
                     parameters = list(cutoffs = c(400, 475, 550, 625),
                                       percentiles = c(5, 10, 25, 75, 90, 95),
                                       weights = "JK",
-                                      PVreps = 5),
+                                      PVreps = 5, 
+                                      varpv1=TRUE),
                     input = list(type = "IEA",
                                  prefixes = c("bsg", "bcg", "bst", "btm", "bts"),
                                  student = "bsg",
@@ -99,6 +103,36 @@ timss8_conf <- list(variables = list(pvlabelpref="BSMMAT",
                                  cnt_part = c(-8, -6))
 )
 
+
+timss2015_conf <- list(variables = list(pvlabelpref="BSMMAT", 
+                                          pvlabelsuff = "",
+                                          weight="TOTWGT",
+                                          jackknifeZone = "JKZONE",
+                                          jackknifeRep = "JKREP"),
+                         parameters = list(cutoffs = c(400, 475, 550, 625),
+                                           percentiles = c(5, 10, 25, 75, 90, 95),
+                                           weights = "JK",
+                                           PVreps = 5,
+                                           varpv1=FALSE),
+                         input = list(type = "IEA",
+                                      prefixes = c("asg", "ash", "acg", "ast", "atg"),
+                                      student = "asg",
+                                      student_colnames1 = c("IDCNTRY", "IDSCHOOL", "IDCLASS", "IDSTUD"),
+                                      student_colnames2 = c("JKREP","JKZONE", "HOUWGT", "SENWGT", "TOTWGT"),
+                                      student_pattern = "^AS.*0[0-5]$", 
+                                      home = "ash",
+                                      home_colnames = c("IDCNTRY", "IDSTUD"),
+                                      school = "acg",
+                                      school_colnames = c("IDCNTRY", "IDSCHOOL", "SCHWGT"),
+                                      teacher = c("ast","atg"),
+                                      teacher_colnames = c("IDCNTRY", "IDTEALIN"),
+                                      student_ids = c("IDCNTRY", "IDSTUD"),
+                                      school_ids = c("IDCNTRY", "IDSCHOOL"),
+                                      type_part = c(-11, -9),
+                                      cnt_part = c(-8, -6))
+)
+
+
 # For PIRLS
 pirls_conf <- list(variables = list(pvlabelpref = "ASRREA0",
                                   pvlabelsuff = "",
@@ -108,7 +142,8 @@ pirls_conf <- list(variables = list(pvlabelpref = "ASRREA0",
                  parameters = list(cutoffs = c(400, 475, 550, 625),
                                    percentiles = c(5, 10, 25, 75, 90, 95),
                                    weights = "JK",
-                                   PVreps = 5),
+                                   PVreps = 5,
+                                   varpv1=TRUE),
                  input = list(type = "IEA",
                               prefixes = c("asg", "ash", "ast", "acg", "atg"),
                               student = "asg",
@@ -127,6 +162,34 @@ pirls_conf <- list(variables = list(pvlabelpref = "ASRREA0",
                               cnt_part = c(-8, -6))
 )
 
+pirls2016_conf <- list(variables = list(pvlabelpref = "ASRREA0",
+                                    pvlabelsuff = "",
+                                    weight="TOTWGT",
+                                    jackknifeZone = "JKZONE",
+                                    jackknifeRep = "JKREP"),
+                   parameters = list(cutoffs = c(400, 475, 550, 625),
+                                     percentiles = c(5, 10, 25, 75, 90, 95),
+                                     weights = "JK",
+                                     PVreps = 5,
+                                     varpv1=FALSE),
+                   input = list(type = "IEA",
+                                prefixes = c("asg", "ash", "ast", "acg", "atg"),
+                                student = "asg",
+                                student_colnames1 = c("IDCNTRY", "IDSCHOOL", "IDCLASS", "IDSTUD"),
+                                student_colnames2 = c("JKREP","JKZONE", "HOUWGT", "SENWGT", "TOTWGT"),
+                                student_pattern = "^ASR.*0[0-5]$", 
+                                home = "ash",
+                                home_colnames = c("IDCNTRY", "IDSTUD"),
+                                school = "acg",
+                                school_colnames = c("IDCNTRY", "IDSCHOOL", "SCHWGT"),
+                                teacher = c("ast","atg"),
+                                teacher_colnames = c("IDCNTRY", "IDTEALIN"),
+                                student_ids = c("IDCNTRY", "IDSTUD"),
+                                school_ids = c("IDCNTRY", "IDSCHOOL"),
+                                type_part = c(-11, -9),
+                                cnt_part = c(-8, -6))
+)
+
 # ICILS
 icils_conf <- list(variables = list(pvlabelpref="BSMMAT", 
                                      pvlabelsuff = "",
